bayespy.nodes.VaryingGaussianMarkovChain.add_plate_axis
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.add_plate_axis